pub struct DiscreteFileStoreNonVolatile<Key, Value, Serde>where
Key: Clone + Eq + Hash + Serialize + for<'a> Deserialize<'a>,
Value: Serialize + for<'a> Deserialize<'a>,
Serde: DiscreteFileSerializerDeserializer<Value>,{ /* private fields */ }Expand description
Before using, strongly consider using the volatile version. Do you really need this cache to rehydrate without hitting the source of record? You are sacrificing reboot to clear corruption and now must consider N vs N+1 schema issues when downgrading or upgrading your application.
Implementations
Sourceimpl<Key, Value, Serde> DiscreteFileStoreNonVolatile<Key, Record<Key, Value>, Serde>where
Key: Clone + Eq + Hash + Serialize + for<'a> Deserialize<'a>,
Value: Serialize + for<'a> Deserialize<'a>,
Serde: DiscreteFileSerializerDeserializer<Record<Key, Value>>,
impl<Key, Value, Serde> DiscreteFileStoreNonVolatile<Key, Record<Key, Value>, Serde>where
Key: Clone + Eq + Hash + Serialize + for<'a> Deserialize<'a>,
Value: Serialize + for<'a> Deserialize<'a>,
Serde: DiscreteFileSerializerDeserializer<Record<Key, Value>>,